@@ -48,6 +48,12 @@ def configure(repl):
     # Highlight matching parethesis.
     repl.highlight_matching_parenthesis = True
 
+    # Line wrapping. (Instead of horizontal scrolling.)
+    repl.wrap_lines = True
+
+    # Mouse support.
+    repl.enable_mouse_support = True
+
     # Complete while typing. (Don't require tab before the
     # completion menu is shown.)
     repl.complete_while_typing = True
@@ -58,6 +64,9 @@ def configure(repl):
     # Paste mode. (When True, don't insert whitespace after new line.)
     repl.paste_mode = False
 
+    # Use the classic prompt. (Display '>>>' instead of 'In [1]'.)
+    repl.prompt_style = 'classic'  # 'classic' or 'ipython'
+
     # History Search.
     # When True, going back in history will filter the history on the records
     # starting with the current input. (Like readline.)
@@ -66,6 +75,10 @@ def configure(repl):
     #       browse through the available completions instead of the history.
     repl.enable_history_search = False
 
+    # Enable auto suggestions. (Pressing right arrow will complete the input,
+    # based on the history.)
+    repl.enable_auto_suggest = False
+
     # Enable open-in-editor. Pressing C-X C-E in emacs mode or 'v' in
     # Vi navigation mode will open the input in the current editor.
     repl.enable_open_in_editor = True
@@ -85,8 +98,10 @@ def configure(repl):
     repl.use_code_colorscheme('pastie')
 
     # Install custom colorscheme named 'my-colorscheme' and use it.
+    """
     repl.install_ui_colorscheme('my-colorscheme', _custom_ui_colorscheme)
     repl.use_ui_colorscheme('my-colorscheme')
+    """
 
     # Add custom key binding for PDB.
     @repl.add_key_binding(Keys.ControlB)
@@ -102,6 +117,7 @@ def configure(repl):
         if b.accept_action.is_returnable:
             b.accept_action.validate_and_handle(event.cli, b)
 
+    """
     # Custom key binding for some simple autocorrection while typing.
     corrections = {
         'impotr': 'import',
@@ -120,6 +136,7 @@ def configure(repl):
                 b.insert_text(corrections[w])
 
         b.insert_text(' ')
+    """
 
 
 # Custom colorscheme for the UI. See `ptpython/layout.py` and
